# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/budget_optimizer',
                'doc_host': 'https://optimizer.mattreda.pro',
                'git_url': 'https://github.com/redam94/budget_optimizer',
                'lib_path': 'budget_optimizer'},
  'syms': { 'budget_optimizer.optimizer': { 'budget_optimizer.optimizer.Optimizer': ( 'optimizer.html#optimizer',
                                                                                      'budget_optimizer/optimizer.py'),
                                            'budget_optimizer.optimizer.Optimizer.__init__': ( 'optimizer.html#optimizer.__init__',
                                                                                               'budget_optimizer/optimizer.py'),
                                            'budget_optimizer.optimizer.Optimizer._load_config': ( 'optimizer.html#optimizer._load_config',
                                                                                                   'budget_optimizer/optimizer.py'),
                                            'budget_optimizer.optimizer.Optimizer._load_loss_fn': ( 'optimizer.html#optimizer._load_loss_fn',
                                                                                                    'budget_optimizer/optimizer.py'),
                                            'budget_optimizer.optimizer.Optimizer._optimizer_array_to_budget': ( 'optimizer.html#optimizer._optimizer_array_to_budget',
                                                                                                                 'budget_optimizer/optimizer.py'),
                                            'budget_optimizer.optimizer.Optimizer.optimize': ( 'optimizer.html#optimizer.optimize',
                                                                                               'budget_optimizer/optimizer.py'),
                                            'budget_optimizer.optimizer.Optimizer.reload_config': ( 'optimizer.html#optimizer.reload_config',
                                                                                                    'budget_optimizer/optimizer.py')},
            'budget_optimizer.utils.funcs': { 'budget_optimizer.utils.funcs.AbstractModel': ( 'utils/helper_func.html#abstractmodel',
                                                                                              'budget_optimizer/utils/funcs.py'),
                                              'budget_optimizer.utils.funcs.AbstractModel.__repr__': ( 'utils/helper_func.html#abstractmodel.__repr__',
                                                                                                       'budget_optimizer/utils/funcs.py'),
                                              'budget_optimizer.utils.funcs.AbstractModel.contributions': ( 'utils/helper_func.html#abstractmodel.contributions',
                                                                                                            'budget_optimizer/utils/funcs.py'),
                                              'budget_optimizer.utils.funcs.AbstractModel.predict': ( 'utils/helper_func.html#abstractmodel.predict',
                                                                                                      'budget_optimizer/utils/funcs.py'),
                                              'budget_optimizer.utils.funcs.load_module': ( 'utils/helper_func.html#load_module',
                                                                                            'budget_optimizer/utils/funcs.py')},
            'budget_optimizer.utils.model_classes': { 'budget_optimizer.utils.model_classes.BaseBudgetModel': ( 'utils/model_classes.html#basebudgetmodel',
                                                                                                                'budget_optimizer/utils/model_classes.py'),
                                                      'budget_optimizer.utils.model_classes.BaseBudgetModel.__init__': ( 'utils/model_classes.html#basebudgetmodel.__init__',
                                                                                                                         'budget_optimizer/utils/model_classes.py'),
                                                      'budget_optimizer.utils.model_classes.BaseBudgetModel._get_budget_to_data': ( 'utils/model_classes.html#basebudgetmodel._get_budget_to_data',
                                                                                                                                    'budget_optimizer/utils/model_classes.py'),
                                                      'budget_optimizer.utils.model_classes.BaseBudgetModel._get_model_loader': ( 'utils/model_classes.html#basebudgetmodel._get_model_loader',
                                                                                                                                  'budget_optimizer/utils/model_classes.py'),
                                                      'budget_optimizer.utils.model_classes.BaseBudgetModel.contributions': ( 'utils/model_classes.html#basebudgetmodel.contributions',
                                                                                                                              'budget_optimizer/utils/model_classes.py'),
                                                      'budget_optimizer.utils.model_classes.BaseBudgetModel.predict': ( 'utils/model_classes.html#basebudgetmodel.predict',
                                                                                                                        'budget_optimizer/utils/model_classes.py')},
            'budget_optimizer.utils.model_helpers': { 'budget_optimizer.utils.model_helpers.AbstractModel': ( 'utils/model_helpers.html#abstractmodel',
                                                                                                              'budget_optimizer/utils/model_helpers.py'),
                                                      'budget_optimizer.utils.model_helpers.AbstractModel.__repr__': ( 'utils/model_helpers.html#abstractmodel.__repr__',
                                                                                                                       'budget_optimizer/utils/model_helpers.py'),
                                                      'budget_optimizer.utils.model_helpers.AbstractModel.contributions': ( 'utils/model_helpers.html#abstractmodel.contributions',
                                                                                                                            'budget_optimizer/utils/model_helpers.py'),
                                                      'budget_optimizer.utils.model_helpers.AbstractModel.predict': ( 'utils/model_helpers.html#abstractmodel.predict',
                                                                                                                      'budget_optimizer/utils/model_helpers.py'),
                                                      'budget_optimizer.utils.model_helpers.load_module': ( 'utils/model_helpers.html#load_module',
                                                                                                            'budget_optimizer/utils/model_helpers.py'),
                                                      'budget_optimizer.utils.model_helpers.load_yaml': ( 'utils/model_helpers.html#load_yaml',
                                                                                                          'budget_optimizer/utils/model_helpers.py')}}}
